==> haskell-wreq-0.5.3.2-42-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.3.2
id: wreq-0.5.3.2-5I1J0fa89jVEq6Beo6STNW
key: wreq-0.5.3.2-5I1J0fa89jVEq6Beo6STNW
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: 257126f4cfc97af0ed6448e500309d6c
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wreq-0.5.3.2
hs-libraries: HSwreq-0.5.3.2-5I1J0fa89jVEq6Beo6STNW
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal
    authenticate-oauth-1.6-6dEPdqSEpGI1qWif7bktR6 base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-client-0.6.4-CphCGCPwaP0BsiFjxHzhOe
    http-client-tls-0.3.5.3-CWGlN5nDauzDusMovfhUVm
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    lens-4.17.1-D6OjOdeP0MqEPqDMoHvH3T
    lens-aeson-1.0.2-FyMemO7mM8iAydipAM6cmz
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    psqueues-0.2.7.1-5NlnSAVz7shBxXq5J2oBXe template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.3.2-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.3.2
id: wreq-0.5.3.2-6yWk5XaikXWBZMWm8pU0d6
key: wreq-0.5.3.2-6yWk5XaikXWBZMWm8pU0d6
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: 21ed190972f70635f630070bc7c8085c
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wreq-0.5.3.2
hs-libraries: HSwreq-0.5.3.2-6yWk5XaikXWBZMWm8pU0d6
depends:
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal
    authenticate-oauth-1.6-6dEPdqSEpGI1qWif7bktR6 base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-client-0.6.4-CphCGCPwaP0BsiFjxHzhOe
    http-client-tls-0.3.5.3-Co8TJNg4aLzFj3kJ71hnLP
    http-types-0.12.3-KTFxmt6v4566xpn9x45HFw
    lens-4.17.1-D6OjOdeP0MqEPqDMoHvH3T
    lens-aeson-1.0.2-FyMemO7mM8iAydipAM6cmz
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    psqueues-0.2.7.1-5NlnSAVz7shBxXq5J2oBXe template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
